@@ -21,9 +21,9 @@ class IconButton(ttk.Frame):
             dimmable: bool = False,
             icon_path: str = '',
             **kwargs):
-        super().__init__(master, borderwidth=1, relief="raised", **kwargs)
+        super().__init__(master, borderwidth=1, relief='raised', **kwargs)
         self.command = command
-        self._state = 'normal'
+        self._state = tk.NORMAL
         self.text = button_text
         self.icon = icon
 
@@ -74,6 +74,8 @@ class IconButton(ttk.Frame):
         event.widget.winfo_toplevel().config(cursor=HAND)
 
     def _on_click(self, *args):
+        if self._state == tk.DISABLED:
+            return
         if self.command:
             self.command()
 
@@ -225,12 +227,15 @@ icon_buttons = {
     'new': (text.NEW, 'new'),
     'next': (text.NEXT, 'next'),
     'open': (text.OPEN, 'open'),
+    'pause': (text.PAUSE, 'pause'),
     'preferences': (text.PREFERENCES, 'preferences'),
     'previous': (text.PREVIOUS, 'previous'),
     'process': (text.PROCESS, 'process'),
+    'redo': (text.REDO, 'redo'),
     'refresh': (text.REFRESH, 'refresh'),
     'rename': (text.RENAME, 'rename'),
     'report': (text.REPORT, 'report'),
+    'reset': (text.RESET, 'reset'),
     'run': (text.RUN, 'start'),
     'save': (text.SAVE, 'save'),
     'send': (text.SEND, 'send'),
