@@ -19,13 +19,16 @@ NO = 'No'
 NO_SUCH_FILE = 'no such file or directory'
 OK = 'OK'
 OPEN = 'Open'
+PAUSE = 'Pause'
 PREFERENCES = 'Preferences'
 PREVIOUS = 'Prev'
 PROCESS = 'Process'
 QUIT = 'Quit'
+REDO = 'Redo'
 REFRESH = 'Refresh'
 REPORT = 'Report'
 RENAME = 'Rename'
+RESET = 'Reset'
 RUN = 'Run'
 SAVE = 'Save'
 SAVE_PDF = 'Save as PDF'
